<?php
namespace FiloBlu\Storelocator\Block\PickUpInStore;

/**
 * Class ConfirmReceived
 * @package FiloBlu\Storelocator\Block\PickUpInStore
 */
class Rmarefused extends \Magento\Framework\View\Element\Template
{
    /**
     * @var \FiloBlu\Storelocator\Helper\Data
     */
    protected $helper;
    /**
     * @var \Magento\Framework\Registry
     */
    protected $_coreRegistry;
    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $_storeManager;
    /**
     * @var \Magento\Framework\App\Request\Http
     */
    protected $request;
    protected $_rma;

    /**
     * ConfirmReceived constructor.
     * @param \Magento\Framework\View\Element\Template\Context $context
     * @param \FiloBlu\Storelocator\Helper\Data $helper
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\App\Request\Http $request
     */
    public function __construct(
        \Magento\Framework\View\Element\Template\Context $context,
        \FiloBlu\Storelocator\Helper\Data $helper,
        \Magento\Framework\Registry $registry,
        \Magento\Rma\Model\Rma $rma,
        \Magento\Framework\App\Request\Http $request
    )
    {
        parent::__construct($context);
        $this->helper = $helper;
        $this->_coreRegistry = $registry;
        $this->_storeManager = $context->getStoreManager();
        $this->_rma = $rma;
        $this->request = $request;
    }

    /**
     * @return bool
     */
    public function isAlreadyConfirmed() {
      return $this->_coreRegistry->registry("pickupinstore_rma_refused")->getPickupInStoreRmaReceivedDate() != null;
    }

    /**
     * @return string
     */
    public function getBaseUrl() {
      return $this->_storeManager->getStore()->getBaseUrl();
    }

    /**
     * @return string
     */
    public function getParams() {
      if ($params = $this->getRequest()->getParams()) {
        $increment_id = isset($params["increment_id"]) ? $params["increment_id"] : "";
        $hash = isset($params["hash"]) ? $params["hash"] : "";
        $rma_id = isset($params["rma_id"]) ? $params["rma_id"] : "";
        return "increment_id=" . $increment_id . "&hash=" . $hash . "&rma_id=" . $rma_id;
      }
      else {
        return "";
      }

    }

    /**
     * @return bool
     */
    public function getRmaStatus(){
      $params = $this->getParams();

      if(isset($params["rma_id"]) && (int)$params["rma_id"] > 0) {
        $rma = $this->_rma->load($params["rma_id"]);
        return $rma->getStatus() != 'pending';
      }
      return false;
    }
}
